@@ -56,6 +56,12 @@ public:
 	const char* paramVib;
 	
 		
+	void startBackground();
+	void stopBackground();
+	pthread_t backgroundThread;
+
+	int backgroundPlaying;
+	
 	SoundEngine* soundEngine;	
 	
 	int sound;
