@@ -13,6 +13,9 @@
  
  int main(int argc, char **argv)
  {
+	   
+ QApplication::setGraphicsSystem(QString("opengl"));
+	   
  QApplication app(argc, argv);
 
  qsrand(QTime(0,0,0).secsTo(QTime::currentTime()));
@@ -39,6 +42,8 @@
 	Sheep::view=view;
 	Fence::view=view;
 
+	QWidget::connect(game->soundEngine->background,SIGNAL(aboutToFinish()),view,SLOT(rewindBackgroundSound()));
+
      for (int i = 0; i < sheepCount; ++i) 
      {
          Sheep *sheep = new Sheep();
